Book.is_series_collection
This is True if the book is a collection containing more than one book from a single series
Book.is_series_collection: bool
Notes
Does not work for collection with multiple authors
This is True if the book is a collection containing more than one book from a single series
Book.is_series_collection: bool
Does not work for collection with multiple authors