io.NameFormatter
This Enum helps control the formatting of Narrator names.
Usage
io.NameFormatterAttributes
| Name | Description |
|---|---|
| long | This Enum helps control the formatting of Narrator names. |
| name | This Enum helps control the formatting of Narrator names. |
| short | This Enum helps control the formatting of Narrator names. |
long
This Enum helps control the formatting of Narrator names.
long="name_with_long_tag"
name
This Enum helps control the formatting of Narrator names.
name="name"
short
This Enum helps control the formatting of Narrator names.
short="name_with_short_tag"